package org.dromara.system.service;

import org.dromara.system.domain.Region;
import org.dromara.system.domain.bo.RegionBoStr;
import org.dromara.system.domain.vo.RegionVo;
import org.dromara.system.domain.bo.RegionBo;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.common.mybatis.core.page.PageQuery;

import java.util.Collection;
import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author Lion Li
 * @date 2024-12-13
 */
public interface IRegionService {

    /**
     * 查询【请填写功能名称】
     */
    RegionVo queryById(String regionId);

    /**
     * 查询【请填写功能名称】列表
     */
    TableDataInfo<RegionVo> queryPageList(RegionBo bo, PageQuery pageQuery);

    /**
     * 查询【请填写功能名称】列表
     */
    List<RegionVo> queryList(RegionBo bo);

    /**
     * 新增【请填写功能名称】
     */
    Boolean insertByBo(RegionBo bo);

    /**
     * 修改【请填写功能名称】
     */
    Boolean updateByBo(RegionBo bo);

    /**
     * 校验并批量删除【请填写功能名称】信息
     */
    Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid);

    List<RegionVo> selectByRoomId(String roomId);
}
